@@ -25,9 +25,9 @@ sub date {
 
     my $hbits = pack("b8"x5,
 		     ".....11.",
-		     "...11.1.",
-		     ".11...1.",
-		     "...11.1.",
+		     "...1111.",
+		     ".111111.",
+		     "...1111.",
 		     ".....11.");
     eval {
 	$top->DefineBitmap($HDECBITMAP => 8,5, $hbits);
@@ -77,7 +77,7 @@ sub date {
 
     single_widget('Only time', -fields => 'time');
 
-    my $i1 = single_widget('Non-editable', -editable => 0, -value => 'now');
+    my $i1 = single_widget('Read-only', -editable => 0, -value => 'now');
     my $timer;
     $timer = $w[$i1]->repeat(999, sub {
 				 if (Tk::Exists($w[$i1])) {
@@ -92,26 +92,6 @@ sub date {
 		  -timefmt => "%2H.%2M.%2S",
 		  -value => 'now',
 		  -choices => ['today', 'reset'],
-		  -command => sub { print STDERR join(" ", @_), "\n" },
-		 );
-
-    single_widget('All arrows',
-		  -value => 'now',
-		  -allarrows => 1,
-		  -state => 'normal',#'disabled',
-		  -command => sub { print STDERR join(" ", @_), "\n" },
-		 );
-
-    single_widget('All arrows, readonly',
-		  -value => 'now',
-		  -allarrows => 1,
-		  -readonly => 1,
-		  -command => sub { print STDERR join(" ", @_), "\n" },
-		 );
-
-    single_widget('Horizontal arrows',
-		  -value => 'now',
-		  -orient => "horiz",
 		 );
 
     single_widget('With weekday',
@@ -120,13 +100,6 @@ sub date {
 		  -value => 'now',
 		 );
 
-    single_widget('Only parts',
-		  -datefmt => "%2d.%2m",
-		  -timefmt => "%2H.%2M",
-		  -value => 'now',
-		  -choices => ['today', 'reset'],
-		 );
-
     my $i2;
     $i2 = single_widget
       ('All options set',
@@ -136,45 +109,32 @@ sub date {
 		    ['christmas' => { 'm' => 12,
 				      'd' => 25 }],
 		    'reset'],
-       -selectlabel => 'Whle:',
        -bell => 0,
        -repeatinterval => 10,
        -repeatdelay => 300,
        -borderwidth => 2,
        -relief => 'raised',
-       -innerbg => 'white',
-       -innerfg => 'red',
+       -bg => 'white',
+       -fg => 'red',
        -orient => 'horiz',
-       -weekdays => ['nedjelja', 'ponedjeljak', 'utorak', 'srijeda',
-		     'cetvrtak', 'petak', 'subota'],
-       -monthnames =>
-       ["sije\x{010D}anj", "velja\x{010D}a", "o\x{017E}ujak", "travanj",
-	"svibanj", "lipanj", "srpanj", "kolovoz", "rujan",
-	"listopad", "studeni", "prosinac"],
-       -monthmenu => 1,
        -incbitmap => $HINCBITMAP,
        -decbitmap => $HDECBITMAP,
        -command => sub {
-	   warn $w[$i2]->get("%x, %X");
+	   $l1[$i2]->configure(-text => $w[$i2]->get("%x, %X"));
 # segfaults... why?
 #	   $l1[$i2]->configure(-text => $w[$i2]->get("%+"));
-       },
-       -check => 1,
+       }
       );
+    $l1[$i2]->configure(-textvariable => undef);
 
 
-    my $getvalb = $f->Button
-      (-text => 'Get values',
-       -command => sub {
-	   warn "Tie values:\n";
-	   for(my $i = 0; $i <= $#w; $i++) {
-	       $date[$i] = $w[$i]->get("%x, %X");
-	       if (defined $w[$i]->cget(-variable)) {
-		   warn "  $i: " . $ {$w[$i]->cget(-variable)} . "\n";
-	       }
-	   }
-       })->grid(-row => $row, -column => 0,
-		-columnspan => 7, -sticky => 'ew');
+    my $getvalb = $f->Button(-text => 'Get values',
+			     -command => sub {
+				 for(my $i = 0; $i <= $#w; $i++) {
+				     $date[$i] = $w[$i]->get("%x, %X");
+				 }
+			     })->grid(-row => $row, -column => 0,
+				      -columnspan => 7, -sticky => 'ew');
     $getvalb->invoke();
 }
 
@@ -208,8 +168,6 @@ return 1 if caller();
 require WidgetDemo;
 
 $MW = new MainWindow;
-$MW->geometry("+0+0");
-$MW->Button(-text => 'Close',
-	    -command => sub { $MW->destroy })->pack;
+$MW->geometry("-0-0");
 date('date');
 MainLoop;
